==> nest-infrastructure-middleware-rdb-3.5.3.0-20251216.064212-15-sources.jar: com/digiwin/dap/nest/infrastructure/middleware/rdb/datasource/DwDataSourceFactory.java <==
package com.digiwin.dap.nest.infrastructure.middleware.rdb.datasource;

import com.digiwin.dap.nest.kernel.core.config.DwConfig;
import com.digiwin.dap.nest.kernel.core.config.processor.JaYamlProcessor;
import com.digiwin.dap.nest.kernel.core.util.DwShutdownHookUtil;
import com.digiwin.dap.nest.kernel.core.util.DwStringUtil;
import com.digiwin.dap.nest.kernel.core.util.reflect.JaReflectUtil;
import com.digiwin.dap.nest.infrastructure.middleware.rdb.datasource.config.DwDataSourceConfig;
import com.digiwin.dap.nest.infrastructure.middleware.rdb.datasource.config.DwDataSourcePoolConfig;
import com.digiwin.dap.nest.infrastructure.middleware.rdb.datasource.hikari.DwHikariDataSourceProcessor;
import com.digiwin.dap.nest.infrastructure.middleware.rdb.jdbc.DwJdbcUrlProcessor;
import com.digiwin.dap.nest.infrastructure.middleware.rdb.jdbc.config.JdbcPropertyConfig;
import com.zaxxer.hikari.HikariDataSource;
import lombok.SneakyThrows;

import javax.sql.DataSource;
import java.lang.reflect.Field;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class DwDataSourceFactory {

    private DwDataSourceFactory() {
    }

    private static Map<String, DataSource> dataSourcePool = null;

    public static Map<String, DataSource> get() {
        return dataSourcePool;
    }

    public static synchronized void create() {
        if (null == dataSourcePool) {
            dataSourcePool = new ConcurrentHashMap<>();
        }
        DwDataSourcePoolConfig dataSourcePoolConfig = JaYamlProcessor.getConfig(DwConfig.KeyPrefix + "datasource", DwDataSourcePoolConfig.class);
        dataSourcePoolConfig.getPool().forEach((name, dataSourceConfig) -> {
            if (!dataSourcePool.containsKey(name)) {
                HikariDataSource dataSource = DwHikariDataSourceProcessor.create(name, dataSourceConfig);
                dataSourcePool.put(name, dataSource);
                DwShutdownHookUtil.add("DataSource-" + name, dataSource::close);
            }
        });
    }

    @SneakyThrows
    public static String getJdbcUrl(DwDataSourceConfig dataSourceConfig) {
        if (DwStringUtil.isNotEmpty(dataSourceConfig.getJdbcUrl())) {
            return dataSourceConfig.getJdbcUrl();
        }
        return DwJdbcUrlProcessor.get(dataSourceConfig.getIp()
                , dataSourceConfig.getPort()
                , dataSourceConfig.getDatabase()
                , dataSourceConfig.getJdbcUrlParam());
    }

    @SneakyThrows
    public static Map<String, Object> getJdbcProperty(DwDataSourceConfig dataSourceConfig) {
        JdbcPropertyConfig property = dataSourceConfig.getJdbcProperty();
        List<Field> allFields = JaReflectUtil.getAllFields(JdbcPropertyConfig.class);
        Map<String, Object> map = new HashMap<>(allFields.size());
        for (Field field : allFields) {
            field.setAccessible(true);
            map.put(field.getName(), field.get(property));
        }
        return map;
    }
}

==> nest-infrastructure-middleware-rdb-5.5.0.1000-20251217.112142-5-sources.jar: com/digiwin/dap/nest/infrastructure/middleware/rdb/datasource/DwDataSourceFactory.java <==
package com.digiwin.dap.nest.infrastructure.middleware.rdb.datasource;

import com.digiwin.dap.nest.kernel.core.config.DwConfig;
import com.digiwin.dap.nest.kernel.core.config.processor.DwYamlProcessor;
import com.digiwin.dap.nest.kernel.core.util.DwShutdownHookUtil;
import com.digiwin.dap.nest.kernel.core.util.DwStringUtil;
import com.digiwin.dap.nest.kernel.core.util.reflect.JaReflectUtil;
import com.digiwin.dap.nest.infrastructure.middleware.rdb.datasource.config.DwDataSourceConfig;
import com.digiwin.dap.nest.infrastructure.middleware.rdb.datasource.config.DwDataSourcePoolConfig;
import com.digiwin.dap.nest.infrastructure.middleware.rdb.datasource.hikari.DwHikariDataSourceProcessor;
import com.digiwin.dap.nest.infrastructure.middleware.rdb.jdbc.DwJdbcUrlProcessor;
import com.digiwin.dap.nest.infrastructure.middleware.rdb.jdbc.config.JdbcPropertyConfig;
import com.zaxxer.hikari.HikariDataSource;
import lombok.SneakyThrows;

import javax.sql.DataSource;
import java.lang.reflect.Field;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class DwDataSourceFactory {

    private DwDataSourceFactory() {
    }

    private static Map<String, DataSource> dataSourcePool = null;

    public static Map<String, DataSource> get() {
        return dataSourcePool;
    }

    public static synchronized void create() {
        if (null == dataSourcePool) {
            dataSourcePool = new ConcurrentHashMap<>();
        }
        DwDataSourcePoolConfig dataSourcePoolConfig = DwYamlProcessor.getConfig(DwConfig.KeyPrefix + "datasource", DwDataSourcePoolConfig.class);
        dataSourcePoolConfig.getPool().forEach((name, dataSourceConfig) -> {
            if (!dataSourcePool.containsKey(name)) {
                HikariDataSource dataSource = DwHikariDataSourceProcessor.create(name, dataSourceConfig);
                dataSourcePool.put(name, dataSource);
                DwShutdownHookUtil.add("DataSource-" + name, dataSource::close);
            }
        });
    }

    @SneakyThrows
    public static String getJdbcUrl(DwDataSourceConfig dataSourceConfig) {
        if (DwStringUtil.isNotEmpty(dataSourceConfig.getJdbcUrl())) {
            return dataSourceConfig.getJdbcUrl();
        }
        return DwJdbcUrlProcessor.get(dataSourceConfig.getIp()
                , dataSourceConfig.getPort()
                , dataSourceConfig.getDatabase()
                , dataSourceConfig.getJdbcUrlParam());
    }

    @SneakyThrows
    public static Map<String, Object> getJdbcProperty(DwDataSourceConfig dataSourceConfig) {
        JdbcPropertyConfig property = dataSourceConfig.getJdbcProperty();
        List<Field> allFields = JaReflectUtil.getAllFields(JdbcPropertyConfig.class);
        Map<String, Object> map = new HashMap<>(allFields.size());
        for (Field field : allFields) {
            field.setAccessible(true);
            map.put(field.getName(), field.get(property));
        }
        return map;
    }
}
